@@ -711,31 +711,31 @@ extern "C" {
 	    Rprintf("\tparameter\tacceptance\ttuning\n");
 	    for(j = 0, i = 0; j < m; j++){
 	      for(k = j; k < m; k++, i++){
-		Rprintf("\tA[%i,%i]\t\t%3.1f%\t\t%1.2f\n", j+1, k+1, 100.0*REAL(accept_r)[b*nParams+AIndx+i], exp(tuning[AIndx+i]));
+		Rprintf("\tA[%i,%i]\t\t%3.1f\t\t%1.2f\n", j+1, k+1, 100.0*REAL(accept_r)[b*nParams+AIndx+i], exp(tuning[AIndx+i]));
 	      }
 	    }
 	    if(nugget){
 	      if(PsiDiag){
 		for(j = 0; j < m; j++){
-		  Rprintf("\tPsi[%j,%j]\t\t%3.1f%\t\t%1.2f\n", j+1, j+1, 100.0*REAL(accept_r)[b*nParams+LIndx+j], exp(tuning[LIndx+j]));
+		  Rprintf("\tPsi[%i,%i]\t%3.1f\t\t%1.2f\n", j+1, j+1, 100.0*REAL(accept_r)[b*nParams+LIndx+j], exp(tuning[LIndx+j]));
 		}
 	      }else{
 		Rprintf("\n");
 		for(j = 0, i = 0; j < m; j++){
 		  for(k = j; k < m; k++, i++){
-		    Rprintf("\tL[%i,%i]\t\t%3.1f%\t\t%1.2f\n", j+1, k+1, 100.0*REAL(accept_r)[b*nParams+LIndx+i], exp(tuning[LIndx+i]));
+		    Rprintf("\tL[%i,%i]\t\t%3.1f\t\t%1.2f\n", j+1, k+1, 100.0*REAL(accept_r)[b*nParams+LIndx+i], exp(tuning[LIndx+i]));
 		  }
 		}
 	      }
 	    }
 	    Rprintf("\n");
 	    for(j = 0; j < m; j++){
-	      Rprintf("\tphi[%i]\t\t%3.1f%\t\t%1.2f\n", j+1, 100.0*REAL(accept_r)[b*nParams+phiIndx+j], exp(tuning[phiIndx+j]));
+	      Rprintf("\tphi[%i]\t\t%3.1f\t\t%1.2f\n", j+1, 100.0*REAL(accept_r)[b*nParams+phiIndx+j], exp(tuning[phiIndx+j]));
 	    }
 	    if(covModel == "matern"){
 	      Rprintf("\n");
 	      for(j = 0; j < m; j++){
-		Rprintf("\tnu[%i]\t\t%3.1f%\t\t%1.2f\n", j+1, 100.0*REAL(accept_r)[b*nParams+nuIndx+j], exp(tuning[nuIndx+j]));
+		Rprintf("\tnu[%i]\t\t%3.1f\t\t%1.2f\n", j+1, 100.0*REAL(accept_r)[b*nParams+nuIndx+j], exp(tuning[nuIndx+j]));
 	      } 
 	    }
 	  }else{
