@@ -1,7 +1,5 @@
-#include <iostream>
+#include <algorithm>
 #include <string>
-using namespace std;
-
 #include <R.h>
 #include <Rinternals.h>
 #include <R_ext/Linpack.h>
@@ -55,10 +53,10 @@ extern "C" {
     double *knotsCoordsD = REAL(knotsCoordsD_r);
 
     bool modPP = static_cast<bool>(INTEGER(modPP_r)[0]);
-    string covModel = CHAR(STRING_ELT(covModel_r,0));
+    std::string covModel = CHAR(STRING_ELT(covModel_r,0));
 
     //priors
-    string betaPrior = CHAR(STRING_ELT(betaPrior_r,0));
+    std::string betaPrior = CHAR(STRING_ELT(betaPrior_r,0));
     double *betaMu = NULL;
     double *betaC = NULL;
     
@@ -529,9 +527,9 @@ extern "C" {
 	  REAL(tuning_r)[b*nParams+j] = tuning[j];
 	  
 	  if(accept[j]/batchLength > acceptRate){
-	    tuning[j] += min(0.01, 1.0/sqrt(static_cast<double>(b)));
+	    tuning[j] += std::min(0.01, 1.0/sqrt(static_cast<double>(b)));
 	  }else{
-	    tuning[j] -= min(0.01, 1.0/sqrt(static_cast<double>(b)));
+	    tuning[j] -= std::min(0.01, 1.0/sqrt(static_cast<double>(b)));
 	  }
 	  accept[j] = 0.0;
 	}
